==> discord_api.py-0.2.1-py3-none-any.whl: discord_api/http.py <==
from aiohttp import ClientSession
from .gateway import DiscordGateway
from .command import Command
from .errors import *
from .role import Role
from .member import Member
from asyncio import sleep

class Route:
    def __init__(self, method, path):
        self.method = method
        self.path = path

class DiscordRequest:
    def __init__(self, client):
        self.session = ClientSession(loop = client.loop, json_serialize = client.json.dumps)
        self.baseurl = "https://discord.com/api/v9"
        self.token = None
        self.client = client

    async def ws_connect(self, uri):
        return await self.session.ws_connect(uri)

    def _token(self, token):
        self.token = token

    async def json_or_text(self, r):
        if r.headers["Content-Type"] == "application/json":
            return await r.json()

    async def get_ws_url(self):
        data = await self.request(Route("GET", "/gateway"))
        return data["url"]

    async def request(self, route:Route, *args, **kwargs):
        headers = {
            "Authorization": f"Bot {self.token}"
        }
        if kwargs.get("json"):
            headers["Content-Type"] = "application/json"
        kwargs["headers"] = headers
        for t in range(5):
            async with self.session.request(route.method, self.baseurl + route.path, *args, **kwargs) as r:
                if r.status == 429:
                    data = await r.json()
                    if data["global"] is True:
                        raise ApiError("Now api is limit. Wait a minute please.")
                    else:
                        await sleep(data["retry_after"])
                elif r.status == 404:
                    raise ApiError("Not Found Error")
                elif 300 > r.status >= 200:
                    return await self.json_or_text(r)

    async def static_login(self):
        data = await self.request(Route("GET", "/users/@me"))
        return data

    async def send_message(self, channelid, payload):
        await self.request(Route("POST", f"/channels/{channelid}/messages"), json = payload)

    async def slash_callback(self, interaction, payload):
        json = {
            "type": 4,
            "data": payload
        }
        return await self.request(Route("POST", f"/interactions/{interaction.id}/{interaction.token}/callback"), json = json)

    async def fetch_commands(self):
        return await self.request(Route("GET", f"/applications/{self.client.user.id}/commands"))

    async def add_command(self, command:Command):
        await self.request(Route("POST", f"/applications/{self.client.user.id}/commands"), json = command.to_dict())
        
    async def add_role(self, member:Member, role:Role):
        await self.request(Route("PUT", f"/guilds/{member.guild.id}/members/{member.id}/roles/{role.id}"))

==> discord_api.py-1.0.0a4-py3-none-any.whl: discord_api/http.py <==
from discord_api_types import HttpClient

class Route:
    def __init__(self, method, path):
        self.method = method
        self.path = path

class DiscordRequest(HttpClient):
    def __init__(self, client):
        super().__init__(client.loop)

    def _token(self, token):
        self.token = token

    async def get_ws_url(self):
        data = await self.request(Route("GET", "/gateway"))
        return data["url"]

    async def request(self, route:Route, *args, **kwargs):
        return await super().request(route.method, route.path, *args, **kwargs)

    async def static_login(self):
        data = await self.request(Route("GET", "/users/@me"))
        return data

    async def send_message(self, channelid, payload):
        await self.request(Route("POST", f"/channels/{channelid}/messages"), json = payload)

    async def slash_callback(self, interaction, payload):
        json = {
            "type": 4,
            "data": payload
        }
        return await self.request(Route("POST", f"/interactions/{interaction.id}/{interaction.token}/callback"), json = json)

    async def fetch_commands(self):
        return await self.request(Route("GET", f"/applications/{self.client.user.id}/commands"))

    async def add_command(self, command:Command):
        await self.request(Route("POST", f"/applications/{self.client.user.id}/commands"), json = command.to_dict())
        
    async def add_role(self, member:Member, role:Role):
        await self.request(Route("PUT", f"/guilds/{member.guild.id}/members/{member.id}/roles/{role.id}"))

    async def delete_command(self, cmdid):
        await self.request(Route("DELETE", f"/applications/{self.client.user.id}/commands/{cmdid}"))
